summaryrefslogtreecommitdiff
path: root/telepathy-glib/base-protocol.c
diff options
context:
space:
mode:
authorAndre Moreira Magalhaes (andrunko) <andre.magalhaes@collabora.co.uk>2011-11-14 14:36:00 -0200
committerAndre Moreira Magalhaes (andrunko) <andre.magalhaes@collabora.co.uk>2011-11-21 12:46:13 -0200
commit6e827ab08236680481ce027258c517b62a68adf2 (patch)
treebc9e835e1a2b6c5525235ff45f11af2d1418bde0 /telepathy-glib/base-protocol.c
parentf7543ff4873819d61fd5613ad3a11b62fbc22724 (diff)
downloadtelepathy-glib-6e827ab08236680481ce027258c517b62a68adf2.tar.gz
TpBaseProtocol: Rename Get/get to Dup/dup on callbacks to retrieve the supported vcard fields/uri schemes.
Diffstat (limited to 'telepathy-glib/base-protocol.c')
-rw-r--r--telepathy-glib/base-protocol.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/telepathy-glib/base-protocol.c b/telepathy-glib/base-protocol.c
index 695d24756..3fcaced96 100644
--- a/telepathy-glib/base-protocol.c
+++ b/telepathy-glib/base-protocol.c
@@ -423,9 +423,9 @@ tp_cm_param_filter_string_nonempty (const TpCMParamSpec *paramspec,
/**
* TpProtocolAddressingInterface:
* @parent: the parent interface
* @get_supported_uri_schemes: provides the supported URI schemes. Must always
* be implemented.
* @get_supported_vcard_fields: provides the supported vCard fields. Must
* always be implemented.
* @normalize_vcard_address: protocol-specific implementation for normalizing
* vCard addresses.
@@ -437,7 +437,7 @@ tp_cm_param_filter_string_nonempty (const TpCMParamSpec *paramspec,
*/
/**
- * TpBaseProtocolGetSupportedVCardFields:
+ * TpBaseProtocolDupSupportedVCardFields:
* @self: a protocol
*
* Signature of a virtual method to get the supported vCard fields supported by
@@ -450,7 +450,7 @@ tp_cm_param_filter_string_nonempty (const TpCMParamSpec *paramspec,
*/
/**
- * TpBaseProtocolGetSupportedURISchemes:
+ * TpBaseProtocolDupSupportedURISchemes:
* @self: a protocol
*
* Signature of a virtual method to get the supported URI schemes supported by
@@ -1034,15 +1034,15 @@ protocol_prop_addressing_getter (GObject *object,
switch (GPOINTER_TO_INT (getter_data))
{
case PADP_ADDRESSABLE_VCARD_FIELDS:
- g_assert (addr_iface->get_supported_vcard_fields != NULL);
+ g_assert (addr_iface->dup_supported_vcard_fields != NULL);
g_value_take_boxed (value,
- addr_iface->get_supported_vcard_fields (self));
+ addr_iface->dup_supported_vcard_fields (self));
break;
case PADP_ADDRESSABLE_URI_SCHEMES:
- g_assert (addr_iface->get_supported_uri_schemes != NULL);
+ g_assert (addr_iface->dup_supported_uri_schemes != NULL);
g_value_take_boxed (value,
- addr_iface->get_supported_uri_schemes (self));
+ addr_iface->dup_supported_uri_schemes (self));
break;
default:
@@ -423,9 +423,9 @@ tp_cm_param_filter_string_nonempty (const TpCMParamSpec *paramspec,
* TpProtocolAddressingInterface:
* @parent: the parent interface
- * @get_supported_uri_schemes: provides the supported URI schemes. Must always
+ * @dup_supported_uri_schemes: provides the supported URI schemes. Must always
* be implemented.
@@ -423,9 +423,9 @@ tp_cm_param_filter_string_nonempty (const TpCMParamSpec *paramspec,
* be implemented.
- * @get_supported_vcard_fields: provides the supported vCard fields. Must
+ * @dup_supported_vcard_fields: provides the supported vCard fields. Must
* always be implemented.
* @normalize_vcard_address: protocol-specific implementation for normalizing